@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2014 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2015 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,8 +20,6 @@
 #include "tig/refdb.h"
 #include "tig/util.h"
 
-struct graph_canvas;
-
 enum align {
 	ALIGN_LEFT,
 	ALIGN_RIGHT
@@ -33,7 +31,7 @@ bool draw_text(struct view *view, enum line_type type, const char *string);
 bool PRINTF_LIKE(3, 4) draw_formatted(struct view *view, enum line_type type, const char *format, ...);
 bool draw_graphic(struct view *view, enum line_type type, const chtype graphic[], size_t size, bool separator);
 bool draw_field(struct view *view, enum line_type type, const char *text, int width, enum align align, bool trim);
-bool draw_lineno(struct view *view, struct view_column *column, unsigned int lineno);
+bool draw_lineno(struct view *view, struct view_column *column, unsigned int lineno, bool add_offset);
 bool view_column_draw(struct view *view, struct line *line, unsigned int lineno);
 
 void redraw_view(struct view *view);
