@@ -53,6 +53,7 @@
 #include <sys/file.h>
 #include <time.h>
 #include <fcntl.h>
+#include <libgen.h>
 #include <termios.h>
 
 #include <regex.h>
@@ -65,6 +66,10 @@
 #include <execinfo.h>
 #endif
 
+#ifdef HAVE_PATHS_H
+#include <paths.h>
+#endif
+
 /* ncurses(3): Must be defined to have extended wide-character functions. */
 #define _XOPEN_SOURCE_EXTENDED 1
 
@@ -95,6 +100,11 @@
 #undef FALSE
 #endif
 
+#ifndef newscr
+/* `newscr` is a ncurses-ism, and doesn't exist in netbsd-curses. (#790) */
+#define newscr curscr
+#endif
+
 #if __GNUC__ >= 3
 #define TIG_NORETURN __attribute__((__noreturn__))
 #define PRINTF_LIKE(fmt, args) __attribute__((format (printf, fmt, args)))
@@ -113,9 +123,9 @@
 #define STRING_SIZE(x)	(sizeof(x) - 1)
 
 #define SIZEOF_STR	1024	/* Default string size. */
+#define SIZEOF_MED_STR	8192	/* Medium string size. */
 #define SIZEOF_REF	256	/* Size of symbolic or SHA1 ID. */
 #define SIZEOF_REV	41	/* Holds a SHA-1 and an ending NUL. */
-#define SIZEOF_CMD	8192	/* Default command string size. */
 
 /* This color name can be used to refer to the default term colors. */
 #define COLOR_DEFAULT	(-1)
@@ -150,6 +160,7 @@ void TIG_NORETURN usage(const char *message);
 	_(MAIN,   main), \
 	_(DIFF,   diff), \
 	_(LOG,    log), \
+	_(REFLOG, reflog), \
 	_(TREE,   tree), \
 	_(BLOB,   blob), \
 	_(BLAME,  blame), \
