@@ -129,6 +129,7 @@ grep_open(struct view *view, enum open_flags flags)
 {
 	struct grep_state *state = view->private;
 	const char **argv = NULL;
+	enum status_code code;
 
 	if (is_initial_view(view)) {
 		grep_argv = opt_cmdline_args;
@@ -145,7 +146,10 @@ grep_open(struct view *view, enum open_flags flags)
 		state->no_file_group = !column || column->opt.file_name.display != FILENAME_NO;
 	}
 
-	return begin_update(view, NULL, argv, flags);
+	code = begin_update(view, NULL, argv, flags);
+	argv_free(argv);
+	free(argv);
+	return code;
 }
 
 static enum request
@@ -171,12 +175,12 @@ grep_request(struct view *view, enum request request, struct line *line)
 			}
 
 		} else {
-			const char *file_argv[] = { repo.cdup, grep->file, NULL };
+			const char *file_argv[] = { repo.exec_dir, grep->file, NULL };
 
 			clear_position(&file_view->pos);
 			view->env->goto_lineno = grep->lineno;
 			view->env->blob[0] = 0;
-			open_argv(view, file_view, file_argv, repo.cdup, OPEN_SPLIT | OPEN_RELOAD);
+			open_argv(view, file_view, file_argv, repo.exec_dir, OPEN_SPLIT | OPEN_RELOAD);
 		}
 		state->last_file = grep->file;
 		return REQ_NONE;
