@@ -123,6 +123,7 @@ iconv_t opt_iconv_out		= ICONV_NONE;
 char opt_editor[SIZEOF_STR]	= "";
 const char **opt_cmdline_args	= NULL;
 bool opt_log_follow		= false;
+bool opt_word_diff		= false;
 
 /*
  * Mapping between options and command argument mapping.
@@ -253,6 +254,11 @@ update_options_from_argv(const char *argv[])
 			continue;
 		}
 
+		if (!strcmp(flag, "--word-diff") ||
+		    !strcmp(flag, "--word-diff=plain")) {
+			opt_word_diff = true;
+		}
+
 		argv[flags_pos++] = flag;
 	}
 
@@ -1065,6 +1071,11 @@ load_options(void)
 			return error("Failed to format TIG_DIFF_OPTS arguments");
 	}
 
+	if (argv_contains(opt_diff_options, "--word-diff") ||
+	    argv_contains(opt_diff_options, "--word-diff=plain")) {
+		opt_word_diff = true;
+	}
+
 	return SUCCESS;
 }
 
@@ -1475,9 +1486,17 @@ read_repo_config_option(char *name, size_t namelen, char *value, size_t valuelen
 enum status_code
 load_git_config(void)
 {
+	enum status_code code;
+	struct io io;
 	const char *config_list_argv[] = { "git", "config", "--list", NULL };
+	const char *git_worktree = getenv("GIT_WORK_TREE");
 
-	return io_run_load(config_list_argv, "=", read_repo_config_option, NULL);
+	code = io_run_load(&io, config_list_argv, "=", read_repo_config_option, NULL);
+
+	if (git_worktree && *git_worktree)
+		string_ncopy(repo.worktree, git_worktree, strlen(git_worktree));
+
+	return code;
 }
 
 /* vim: set ts=8 sw=8 noexpandtab: */
