@@ -80,9 +80,10 @@ read_repo_info(char *name, size_t namelen, char *value, size_t valuelen, void *d
 static enum status_code
 reload_repo_info(const char **rev_parse_argv)
 {
+	struct io io;
 	struct repo_info_state state = { rev_parse_argv + 2 };
 
-	return io_run_load(rev_parse_argv, "\n", read_repo_info, &state);
+	return io_run_load(&io, rev_parse_argv, "\n", read_repo_info, &state);
 }
 
 enum status_code
