@@ -147,7 +147,7 @@ stage_apply_chunk(struct view *view, struct line *chunk, struct line *single, bo
 		apply_argv[argc++] = "-R";
 	apply_argv[argc++] = "-";
 	apply_argv[argc++] = NULL;
-	if (!io_run(&io, IO_WR, repo.cdup, NULL, apply_argv))
+	if (!io_run(&io, IO_WR, repo.exec_dir, NULL, apply_argv))
 		return false;
 
 	if (single != NULL) {
@@ -459,8 +459,10 @@ stage_request(struct view *view, enum request request, struct line *line)
 
 	/* Check whether the staged entry still exists, and close the
 	 * stage view if it doesn't. */
-	if (view->parent && !stage_exists(view, &stage_status, stage_line_type))
+	if (view->parent && !stage_exists(view, &stage_status, stage_line_type)) {
+		stage_line_type = 0;
 		return REQ_VIEW_CLOSE;
+	}
 
 	refresh_view(view);
 
@@ -499,7 +501,7 @@ stage_open(struct view *view, enum open_flags flags)
 			DIFF_ARGS, diff_context_arg(), ignore_space_arg(), "--",
 			stage_status.old.name, NULL
 	};
-	static const char *file_argv[] = { repo.cdup, stage_status.new.name, NULL };
+	static const char *file_argv[] = { repo.exec_dir, stage_status.new.name, NULL };
 	const char **argv = NULL;
 	struct stage_state *state = view->private;
 	enum status_code code;
@@ -529,6 +531,7 @@ stage_open(struct view *view, enum open_flags flags)
 		break;
 
 	case LINE_STAT_UNTRACKED:
+		watch_register(&view->watch, WATCH_INDEX_UNTRACKED);
 		argv = file_argv;
 		view->encoding = get_path_encoding(stage_status.old.name, default_encoding);
 		break;
@@ -544,7 +547,7 @@ stage_open(struct view *view, enum open_flags flags)
 		diff_save_line(view, &state->diff, flags);
 
 	view->vid[0] = 0;
-	code = begin_update(view, repo.cdup, argv, flags);
+	code = begin_update(view, repo.exec_dir, argv, flags);
 	if (code == SUCCESS && stage_line_type != LINE_STAT_UNTRACKED) {
 		struct stage_state *state = view->private;
 
